@@ -42,7 +42,7 @@ class ArduStack:
         docker_env = {
             'LAT': home_location.lat,
             'LON': home_location.lon,
-            'ALT': 0.1,
+            'ALT': 5,
             'SPEEDUP': self.config.simulation_speedup
         }
 
@@ -244,14 +244,20 @@ class ArduStack:
         except APIException as ae:
             print(ae)
             while retry_count < self.config.retries:
+                print("Retrying {}".format(retry_count))
                 self._close()
-                time.sleep(2)
+                time.sleep(5)
                 self.container = self._start_container(mission)
                 try:
                     self.vehicle = connect(self.config.connection_string, wait_ready=True, heartbeat_timeout=60)
+                    print(self.vehicle)
                     break
                 except APIException as ae1:
                     pass
+                
+                if self.vehicle is not None:
+                    break
+                retry_count += 1
 
         self.vehicle.add_attribute_listener('location.global_frame', self._location_callback)
 
